########################################
TDK Lambda Genesys 80-65 DC power supply
########################################

.. autoclass:: pymeasure.instruments.tdk.tdk_gen80_65.TDK_Gen80_65
    :members:
    :show-inheritance:
    :inherited-members: CommonBase